@@ -1,27 +1,26 @@
+use 5.008;
 use strict;
 use warnings;
 package Task::PerlFormance;
-# git description: v0.004-2-g1444122
+# git description: v0.005-1-g2adf65e
 
-BEGIN {
-  $Task::PerlFormance::AUTHORITY = 'cpan:SCHWIGON';
-}
-{
-  $Task::PerlFormance::VERSION = '0.005';
-}
+our $AUTHORITY = 'cpan:SCHWIGON';
 # ABSTRACT: Max dependencies for Benchmark::Perl::Formance
+$Task::PerlFormance::VERSION = '0.006';
 
 __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Task::PerlFormance - Max dependencies for Benchmark::Perl::Formance
 
 =head1 VERSION
 
-version 0.005
+version 0.006
 
 =head1 TASK CONTENTS
 
@@ -39,22 +38,14 @@ version 0.005
 
 =head3 L<Benchmark::Perl::Formance::Cargo>
 
-=head3 L<Tapper::TestSuite::Benchmark::Perl::Formance>
+=head3 L<BenchmarkAnything::Reporter>
 
 =head3 L<Test::More>
 
 =head3 L<File::ShareDir>
 
-=head2 SpamAssassin
-
-=head3 L<AAAA::Mail::SpamAssassin>
-
-=head3 L<Mail::SpamAssassin>
-
 =head2 OO
 
-=head3 L<MooseX::Declare>
-
 =head3 L<Moose>
 
 =head3 L<Mouse>
@@ -69,7 +60,7 @@ version 0.005
 
 # =pkg re::engine::Plan9
 
-=head3 L<re::engine::Oniguruma>
+# =pkg re::engine::Oniguruma
 
 =head3 L<re::engine::RE2>
 
@@ -115,10 +106,6 @@ version 0.005
 
 =head3 L<Encode>
 
-=head2 PerlCritic
-
-=head3 L<Perl::Critic>
-
 1;
 
 =head1 AUTHOR
@@ -127,7 +114,7 @@ Steffen Schwigon <ss5@renormalist.net>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2012 by Steffen Schwigon.
+This software is copyright (c) 2016 by Steffen Schwigon.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
